@@ -54,10 +54,13 @@ def transform_timeseries(
         * If all rows have the same value `N <= 0`, then cutoff the dataframe latest `-N` rows after TS shaping and prime the DF (with `__make_predictions` column) so that a forecast is generated only for the last row (thus more efficient). This enables `WHERE T = LATEST - K` with `0 <= K < WINDOW` syntax upstream in MindsDB.
         * If all rows have the same value `N = 1`, then activate streaming inference mode where a single forecast will be emitted for the timestamp inferred by the `_ts_infer_next_row` method. This enables the (already supported) `WHERE T > LATEST` syntax.
         """  # noqa
-        # trigger if __mdb_forecast_offset constant and different from None
-        index = original_df[~original_df['__mdb_forecast_offset'].isin([None])]
-        offset_available = index.shape[0] == len(original_df) and original_df['__mdb_forecast_offset'].nunique() == 1
-        offset = min(int(original_df['__mdb_forecast_offset'].unique()[0]), 1)
+        index = original_df[~original_df['__mdb_forecast_offset'].isin([None])]  # trigger if col is constant & != None
+        offset_available = index.shape[0] == len(original_df) and \
+            original_df['__mdb_forecast_offset'].unique().tolist() != [None]
+        if offset_available:
+            offset = min(int(original_df['__mdb_forecast_offset'].unique()[0]), 1)
+        else:
+            offset = 0
         infer_mode = offset_available and offset == 1
         original_df = original_df.reset_index(drop=True) if infer_mode else original_df
     else:
